// CkSpider.h: interface for the CkSpider class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKSPIDER_H
#define _CKSPIDER_H

#pragma once

class CkString;

/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */

#include "CkObject.h"

// CLASS: CkSpider
class CkSpider  : public CkObject
{
    private:
	void *m_impl;

	// Don't allow assignment or copying these objects.
	CkSpider(const CkSpider &) { } 
	CkSpider &operator=(const CkSpider &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkSpider(void *impl) : m_impl(impl) { }

	CkSpider();
	virtual ~CkSpider();

	// BEGIN PUBLIC INTERFACE

	void get_LastHtmlDescription(CkString &strOut);
	void get_LastHtmlKeywords(CkString &strOut);
	void get_LastHtmlTitle(CkString &strOut);
	void get_LastHtml(CkString &strOut);

	bool get_LastFromCache(void);
	void get_LastModDate(SYSTEMTIME &sysTime);
	void get_LastUrl(CkString &strOut);
	void get_LastModDateStr(CkString &strOut);

	void SkipUnspidered(long index);
	bool FetchRobotsText(CkString &strOut);

	void get_Domain(CkString &strOut);
	void AddMustMatchPattern(const char *pattern);
	void AddAvoidOutboundLinkPattern(const char *pattern);
	bool GetAvoidPattern(long index, CkString &strOut);
	void AddAvoidPattern(const char *pattern);
	bool GetOutboundLink(long index, CkString &strOut);
	bool GetFailedUrl(long index, CkString &strOut);
	bool GetSpideredUrl(long index, CkString &strOut);
	bool GetUnspideredUrl(long index, CkString &strOut);
	bool RecrawlLast(CkString &strOut);

	void ClearOutboundLinks();
	void ClearFailedUrls();
	void ClearSpideredUrls();

	int get_WindDownCount(void);
	void put_WindDownCount(long newVal);

	int get_NumAvoidPatterns(void);
	int get_NumOutboundLinks(void);
	int get_NumFailed(void);
	int get_NumSpidered(void);
	int get_NumUnspidered(void);
	
	bool CrawlNext(CkString &strOut);

	bool get_ChopAtQuery(void);
	void put_ChopAtQuery(bool newVal);

	bool get_AvoidHttps(void);
	void put_AvoidHttps(bool newVal);

	int get_MaxResponseSize(void);
	void put_MaxResponseSize(long newVal);

	int get_MaxUrlLen(void);
	void put_MaxUrlLen(long newVal);

	void get_CacheDir(CkString &strOut);
	void put_CacheDir(const char *dir);

	bool get_UpdateCache(void);
	void put_UpdateCache(bool newVal);

	bool get_FetchFromCache(void);
	void put_FetchFromCache(bool newVal);

	int get_ConnectTimeout(void);
	void put_ConnectTimeout(long newVal);

	int get_ReadTimeout(void);
	void put_ReadTimeout(long newVal);

	void AddUnspidered(const char *url);
	void Initialize(const char *domain);


	// END PUBLIC INTERFACE


};


#endif


